@@ -1,5 +1,4 @@
 import re
-from console.console import Console
 
 class ConnectionStringParser(object):
     def _parse_connection_string(self, cs):
@@ -14,13 +13,10 @@ class ConnectionStringParser(object):
         defaultRet = (False, "", "", -1)
 
         if self._is_malformed_connection_string(conn):
-            choice = Console().console("Connection string may be malformed, continue[n]?: ", default='n')
-            if choice[0] in "nN":
-                return defaultRet
+            return defaultRet
 
         try:
             user, addr, port = self._parse_connection_string(conn)
             return True, user, addr, port
         except Exception as e:
-            print("Connection string malformed: %s " % str(e))
             return defaultRet
